"use client"

import { useEffect, useState } from "react"
import Link from "next/link"

export default function DebugLessonsPage() {
  const [data, setData] = useState<any>(null)
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState<string | null>(null)

  useEffect(() => {
    async function fetchData() {
      try {
        const response = await fetch("/api/debug/lessons")
        const result = await response.json()

        if (result.success) {
          setData(result.data)
        } else {
          setError(result.error || "Une erreur est survenue")
        }
      } catch (error) {
        setError((error as Error).message)
      } finally {
        setLoading(false)
      }
    }

    fetchData()
  }, [])

  if (loading) {
    return <div className="p-8">Chargement...</div>
  }

  if (error) {
    return <div className="p-8 text-red-500">Erreur: {error}</div>
  }

  return (
    <div className="p-8">
      <h1 className="text-2xl font-bold mb-4">Débogage des leçons</h1>

      {data && Object.entries(data).length > 0 ? (
        <div>
          {Object.entries(data).map(([chapter, lessons]: [string, any]) => (
            <div key={chapter} className="mb-6">
              <h2 className="text-xl font-semibold mb-2">Chapitre: {chapter}</h2>
              <ul className="list-disc pl-6">
                {Array.isArray(lessons) &&
                  lessons.map((lesson: string) => (
                    <li key={lesson} className="mb-1">
                      <span className="font-mono text-sm">{lesson}</span>
                      <Link
                        href={`/chapitres/${chapter}/lecons/${lesson.replace(".html", "")}`}
                        className="ml-2 text-blue-500 hover:underline"
                      >
                        Voir la leçon
                      </Link>
                    </li>
                  ))}
              </ul>
            </div>
          ))}
        </div>
      ) : (
        <p>Aucune leçon trouvée.</p>
      )}
    </div>
  )
}
